Documentation
¶
Index ¶
- Constants
- Variables
- func XTerm256Color(n int) color.Color
- type Attr
- type Cell
- type Emu
- func (emu *Emu) ClampSize(p P) P
- func (emu *Emu) Close() error
- func (emu *Emu) GetSize() P
- func (emu *Emu) NeedsPaint()
- func (emu *Emu) Read(p []byte) (int, error)
- func (emu *Emu) ScrPrivModes() *PrivModes
- func (emu *Emu) SetSize(p P) (P, bool)
- func (emu *Emu) Snapshot() *Screen
- func (emu *Emu) Write(p []byte) (int, error)
- type Graphics
- type Grid
- type GridLine
- type Mode
- type Opts
- type P
- type PrivModes
- type R
- type SaveCursor
- type Screen
- type ScreenPrinter
- type TermColor
- type TermColorKind
- type TermCsiOp
- type TermOp
- type Tui
- type VTParser
Constants ¶
const SeqEsc = "\x1b"
const SeqEscCsi = SeqEsc + "["
const SeqEscO = SeqEsc + "O"
Variables ¶
var TermEnv = []string{
"TERM=xterm-256color",
"COLORTERM=truecolor",
}
Functions ¶
func XTerm256Color ¶
Types ¶
type Emu ¶
type Emu struct {
// contains filtered or unexported fields
}
func NewEmu ¶
func NewEmu(userRw io.ReadWriter, tui Tui, opts Opts) *Emu
emu itself is a read/write to be passed to the executable, wrapping the UI that is a rwc as well
func (*Emu) NeedsPaint ¶
func (emu *Emu) NeedsPaint()
func (*Emu) ScrPrivModes ¶
type GridLine ¶
type GridLine struct {
Wrapped bool // Proprietary editor mode only: if true, next line is logical continuation of this one.
// contains filtered or unexported fields
}
type PrivModes ¶
type PrivModes struct {
// contains filtered or unexported fields
}
PrivModes keeps DEC private modes (?n).
func (*PrivModes) AlternateBuffer ¶
func (*PrivModes) AnsiNotVT52 ¶
func (*PrivModes) AppCursorKeys ¶
func (*PrivModes) BracketedPaste ¶
func (*PrivModes) LineFeedNewline ¶
func (*PrivModes) SynchronizedOutput ¶
type SaveCursor ¶
type SaveCursor struct {
// contains filtered or unexported fields
}
type Screen ¶
type Screen struct {
// contains filtered or unexported fields
}
func (*Screen) PrintWithCursor ¶
func (scr *Screen) PrintWithCursor()
type ScreenPrinter ¶
type ScreenPrinter struct {
ColorFn func(offset int, fg, bg TermColor, inverse bool)
SepFn func(offset int)
CursorRune rune // mostly for testing where there are no colors, so a rune is printed for guidance
// contains filtered or unexported fields
}
func NewScreenPrinter ¶
func NewScreenPrinter() *ScreenPrinter
func (*ScreenPrinter) Bprint ¶
func (sp *ScreenPrinter) Bprint(scr *Screen) []byte
type TermColor ¶
type TermColor struct {
// contains filtered or unexported fields
}
func NewTermColorIndexed ¶
func NewTermColorRGB ¶
func (TermColor) Kind ¶
func (tc TermColor) Kind() TermColorKind
type TermColorKind ¶
type TermColorKind uint8
const ( TermColorDefault TermColorKind = iota TermColorIndexed TermColorRGB )
Click to show internal directories.
Click to hide internal directories.